@@ -23,7 +23,7 @@ public:
     void create(std::string base, std::string snapshot, std::filesystem::path snapRoot);
     std::string getPreviousSnapshotOvlId();
     bool references(std::string snapshot);
-    void sync(std::string base, std::filesystem::path snapRoot);
+    bool sync(std::string base, std::filesystem::path snapRoot);
     void setMountOptions(std::unique_ptr<Mount>& mount);
     void setMountOptionsForMount(std::unique_ptr<Mount>& mount);
 
